@@ -10,9 +10,9 @@ urlpatterns = [
     path('change_password/', ChangePasswordForgot.as_view(), name="forgot_password"),
     path('forgot_password/<str:token_id>/<str:hash_code>', ChangePasswordForgot.as_view(),
          name="forgot_password"),
-    generate_url(User(), create=UserCreateView, add_model_to_url=False),
-    generate_url(User(), view=UserListView, add_model_to_url=False),
-    generate_url(User(), update=UserUpdateView, add_model_to_url=False),
+    generate_url(User(), create=UserCreateView),
+    generate_url(User(), view=UserListView),
+    generate_url(User(), update=UserUpdateView),
     path('member/list', MemberListView.as_view(), name='member_list'),
     path('member/create', MemberCreateView.as_view(), name='member_create'),
     path('member/update/<int:pk>', MemberUpdateView.as_view(), name='member_update'),
